@@ -1,4 +1,4 @@
-# Copyright 1998-2004, Paul Johnson (pjcj@cpan.org)
+# Copyright 1998-2005, Paul Johnson (pjcj@cpan.org)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -26,7 +26,7 @@ my %Top_tag_order;
 
 BEGIN
 {
-  $VERSION = "1.14";
+  $VERSION = "1.15";
 
   $Tags =
   {
@@ -231,10 +231,10 @@ sub AUTOLOAD
   goto &$func
 }
 
-use Gedcom::Grammar    1.14;
-use Gedcom::Individual 1.14;
-use Gedcom::Family     1.14;
-use Gedcom::Event      1.14;
+use Gedcom::Grammar    1.15;
+use Gedcom::Individual 1.15;
+use Gedcom::Family     1.15;
+use Gedcom::Event      1.15;
 
 sub new
 {
@@ -334,12 +334,12 @@ sub new
           $l2->add("ADDR", "http://www.pjcj.net");
           $l2 = $l1->add("DATA");
             $l3 = $l2->add("COPR",
-                           'Copyright 1998-2004, Paul Johnson (pjcj@cpan.org)');
+                           'Copyright 1998-2005, Paul Johnson (pjcj@cpan.org)');
         $l1 = $l0->add("NOTE", "");
       for (split /\n/, <<'EOH')
 This output was generated by Gedcom.pm.
-Gedcom.pm is Copyright 1999-2004, Paul Johnson (pjcj@cpan.org)
-Version 1.14 - 5th April 2004
+Gedcom.pm is Copyright 1999-2005, Paul Johnson (pjcj@cpan.org)
+Version 1.15 - 3rd May 2005
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -392,8 +392,8 @@ sub write_xml
 <!--
 
 This output was generated by Gedcom.pm.
-Gedcom.pm is Copyright 1999-2004, Paul Johnson (pjcj@cpan.org)
-Version 1.14 - 5th April 2004
+Gedcom.pm is Copyright 1999-2005, Paul Johnson (pjcj@cpan.org)
+Version 1.15 - 3rd May 2005
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -649,7 +649,7 @@ __END__
 
 Gedcom - a module to manipulate Gedcom genealogy files
 
-Version 1.14 - 5th April 2004
+Version 1.15 - 3rd May 2005
 
 =head1 SYNOPSIS
 
@@ -689,7 +689,7 @@ Version 1.14 - 5th April 2004
 
 =head1 DESCRIPTION
 
-Copyright 1998-2004, Paul Johnson (pjcj@cpan.org)
+Copyright 1998-2005, Paul Johnson (pjcj@cpan.org)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -760,10 +760,8 @@ decisions when I feel the need to make changes to the interface.
 There is a low volume mailing list available for discussing the use of
 Perl in conjunction with genealogical work.  This is an appropriate
 forum for discussing Gedcom.pm and if you use or are interested in this
-module I would encourage you to join the list.  To subscribe to the
-regular list, send a message to majordomo@icomm.ca and put subscribe
-S<perl-gedcom> as the body of the message. To get on the digest version
-of the list, put subscribe S<perl-gedcom-digest>.
+module I would encourage you to join the list.  To subscribe send an
+empty message to S<perl-gedcom-subscribe@perl.org>.
 
 To store my genealogy I wrote a syntax file (gedcom.vim) and used vim
 (http://www.vim.org) to enter the data, and Gedcom.pm to validate and
